pub struct ServerPluginWrapper<S: ServerPlugin> { /* private fields */ }Expand description
Wraps a ServerPlugin so it can be used as a Plugin.
Spawns run at boot, awaits the task during shutdown.
Implementations
Sourceimpl<S: ServerPlugin> ServerPluginWrapper<S>
impl<S: ServerPlugin> ServerPluginWrapper<S>